@@ -12,7 +12,7 @@ LIST_VIEW = """
 @permission_classes((AllowAny, IsAuthenticated))
 def %(lower_model)s_list(request):
 
-    %(lower_model) =  %(model)s.objects.all()
+    %(lower_model) =  %(model).objects.all()
     tmpJson = serializers.serialize("json", %(lower_model))
     tmpObj = json.loads(tmpJson)
     content = {'message': tmpObj}
@@ -27,7 +27,7 @@ DETAILS_VIEW = """
 @permission_classes((AllowAny, IsAuthenticated))
 def %(lower_model)s_details(request, id):
 
-    %(lower_model) = %(model)s.objects.filter(pk=id) 
+    %(lower_model) = %(model).objects.filter(pk=id) 
     tmpJson = serializers.serialize("json", %(lower_model))
     tmpObj = json.loads(tmpJson)
     content = {'message': tmpObj}
@@ -43,7 +43,7 @@ DELETE_VIEW = """
 @permission_classes((AllowAny, IsAuthenticated))
 def %(lower_model)s_delete(request, id):
 
-    item = %(model)s.objects.get(pk=id)
+    item = %(model).objects.get(pk=id)
     item.delete()
     content = {'message': 'done'}
     return JsonResponse(content, status=200)
@@ -62,7 +62,7 @@ CREATE_VIEW="""
 def %(lower_model)s_new(request):
     fields = request.POST.get('fields')
 
-    %(lower_model) = %(model)s()
+    %(lower_model) = %(model)()
     %(lower_model).fields = fields
     %(lower_model).save()
 
@@ -85,7 +85,7 @@ def %(lower_model)s_edit(request):
     descriptions
     '''
     fields = request.POST.get('fields')
-    %(lower_model) = %(model)s.objects.get(pk=id)
+    %(lower_model) = %(model).objects.get(pk=id)
     %(lower_model).fields = fields
     %(lower_model).save()
     content = {'message': 'done'}
